==> haskell-config-schema-1.3.0.0-190-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-JbKAkvM1pN2FPIIiyOiEDt
key:                  config-schema-1.3.0.0-JbKAkvM1pN2FPIIiyOiEDt
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  a28304fd4aa39e7b9b19fe022ba72b8c
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-JbKAkvM1pN2FPIIiyOiEDt
depends:
    base-4.17.2.1 config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH
    containers-0.6.7 free-5.2-8gaqBIccxFkFyc6IgyZldL
    kan-extensions-5.2.7-9PjOyqujQxHDdhyqin8Qf4 pretty-1.1.3.6
    semigroupoids-6.0.1-9xvLUM9nPqADPiveVYegda text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-schema-1.3.0.0-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-9fXw0UIuZkhH4h8STy0QxJ
key:                  config-schema-1.3.0.0-9fXw0UIuZkhH4h8STy0QxJ
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  20cbcd2af5e360a6b3e7ab117a529e4a
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-9fXw0UIuZkhH4h8STy0QxJ
depends:
    base-4.17.2.1 config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH
    containers-0.6.7 free-5.2-C9kbMW4ZlUkFDF5DJjQP8G
    kan-extensions-5.2.7-EoVzTWy6gu77SZt9Ulx2A3 pretty-1.1.3.6
    semigroupoids-6.0.1-4OWDDSnBlNHGZurz9JHoL3 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
